; SET.LSP
; 1/12/1987
; Tony Tanzillo
;
; SET.LSP is a function that adds the command "SET" to AutoCAD.
; It will "extract" the 5 major entity properties (layer, color,
; linetype, elevation, & thickness) from a selected object,
; and MAKE THEM CURRENT DRAWING EDITOR PROPERTIES.
; This is accomplished with a single pick of your pointing
; device.
;
; SET can be a real timesaver when you must switch between
; several elevations and thicknesses at which existing objects
; have already been drawn (just point to the object which
; posseses the desired new current elev & thickness).
; It's also useful if you are one of those folks who use
; 90 zillion layers and linetypes (like me), and can never
; remember all of thier names. This is another example of
; how one can use the drawing itself as a kind-of menu.
;
; Note:
;
;     This command requires the function (pfetch) which can
;     be found in either COPY.LSP or PROP.LSP in the data libraries.
;
; SET will change ALL 5 PROPERTIES (Layer, Color, Linetype, Elevation,
; & Thickness) AT ONCE from the same object. To use it, either add it
; to your ACAD.LSP, or (load"set") at the command prompt. Then just
; type "SET", hit return, and select an object. The properties of the
; selected object WILL BECOME THE CURRENT DRAWING EDITOR PROPERTIES,
; and all subsequently created objects will have the SAME properties
; as the object selected with SET.
;
; SET also has another valueable use, If you do not select an object
; when prompted, SET will simply display the CURRENT drawing editor
; properties on the display, and no properties will be changed.
; If you want to quickly check to see what the current color, linetype,
; elevation and thickness are, Just enter "SET" at the command prompt,
; and press return in response to the "Select object...." prompt.
; If you do this (or "miss" the object you pointed to), The only thing
; SET will do is display the CURRENT drawing editor properties.
;
; Since I've written this command, It, along with COPY.LSP and PROP.LSP
; has enabled me to cut my keyboard input by 50%, and relives me from
; having to tie-up valueable tablet menu boxes with names of layers,
; and linetypes. It also, helps a great deal when doing 3d drawings,
; since it is more intuitive to simply point at an object who's elevation
; or thickness you want to match, eliminating the need for so many LIST
; inquiry's and the rounding of distances which are typical of all AutoCAD
; distance output, depending on the unit precision settings.
;
; Notes
;
; Blocks:      The selected object CANNOT BE A BLOCK, If you select
;              a block, nothing happens.
;
; Colors:      If the color of the selected object is either BYLAYER,
;              OR BYBLOCK, it will not be used, and the Current
;              drawing editor color will not be changed.
;
; Linetypes:   If the linetype of the selected object is BYLAYER, It
;              will not be changed, If it is BYBLOCK, it will be
;              changed to BYBLOCK.
;
;
; Syntax:      The command C:SET has nothing to do with the AutoLISP
;              primitive (set) function, and they can peacefully coexist
;              in the atomlist.
;
; Tony Tanzillo, A/E Automation Systems, 70307,2556
;


(defun C:SET( / e c)
  (if
    (and
      (setq e
        (entsel
         "\nSelect object, or RETURN to view properties: "))

      (not
        (if (eq (pfetch e 1) "INSERT")
         (prompt "\nBlocks not permitted, try again."))))

    (progn
      (setvar "cmdecho" 0)
      (prompt " Setting new editor properties...")

      (command
        "layer" "s" (pfetch e 8) ""
        "color"
          (cond ((and (setq c (pfetch e 62)) (not (zerop c))) c) (t ""))
        "linetype" "s" (orr '((pfetch e 6) "")) "" )

      (mapcar
        '(lambda(x y) (setvar x (orr '((pfetch e y) 0.0))))
        '("elevation" "thickness")
        '(38 39))))

  (prompt
     (strcat
        "\nCurrent color: " (getvar "cecolor")
        "       Current elevation: " (rtos (getvar "elevation"))
        "\nCurrent linetype: " (getvar "celtype")
        "   Current thickness: " (rtos (getvar "thickness")) "  "))

  (setvar "cmdecho" 1) 'ok)


(defun orr(l) (eval (cons 'cond (mapcar 'list l))))

; the fuction (pfetch) can be obtained from either COPY.LSP or
; PROP.LSP on the Autodesk Forum.
